ToastSampler
============

.. currentmodule:: toasty.toast

.. autoclass:: ToastSampler
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ToastSampler.visit_callback

   .. rubric:: Methods Documentation

   .. automethod:: visit_callback
